<?php

$config['file_information'] = false;
$config['include_paths'] = false;
$config['flags'] = false;
$config['included_files'] = false;
$config['constants'] = false;
$config['mixins'] = false;
$config['error_log'] = false;
$config['custom_functions'] = false;
$config['custom_properties'] = false;
$config['gradients'] = false;
$config['layout'] = false;
$config['validation_errors'] = false;