<?php

# Include the required classes
require dirname(__FILE__) . '/Scaffold/Utils.php';
require dirname(__FILE__) . '/Scaffold/CSS.php';
require dirname(__FILE__) . '/Scaffold/Log.php';
require dirname(__FILE__) . '/Scaffold/Scaffold.php';
require dirname(__FILE__) . '/Scaffold/Benchmark.php';
require dirname(__FILE__) . '/Scaffold/Cache.php';
require dirname(__FILE__) . '/Scaffold/Event.php';