/**
* Float
*
* Floats and element, while applying the IE
* fix to the float to prevent the double-margin bug
*
* @type Mixin
* @param $side The direction of the float
*/
=float($side)
{
	float:$side;
	display:inline;
}
