 /**
 * Sharpen an image if it has become blurry due to upscaling or downscaling
 * Useful mainly in flat color images
 * @see https://developer.mozilla.org/en/CSS/image-rendering
 */
=sharpen
{
	image-rendering:-moz-crisp-edges;
	-ms-interpolation-mode:nearest-neighbor;  /* IE 7+ */
}

/**
 * When photos are upscaled or downscaled, they often get blurry. Don't use
 * this on flat color images, they will still appear blurry.
 * Use the +sharpen mixin instead. 
 * @see https://developer.mozilla.org/en/CSS/image-rendering
 */
=high-quality
{
	image-rendering:optimizeQuality;
	-ms-interpolation-mode:bicubic;  /* IE 7+ */
}

/**
 * Optimizes the rendering on images so they
 * appear faster, but at a lower quality. Useful for <video>
 */
=low-quality
{
	image-rendering:optimizeSpeed;
}