<!DOCTYPE html>
<html>
<head>
	<meta charset=utf-8 />
	<title>CSScaffold Error</title>
	
	<style>
		html { background:#e7e7e7; }
		.content { min-width:40%; max-width:60%; margin:30px auto; font:15px/18px Arial; padding:10px 20px; background:#fff; color:#595959; border:1px solid #aaa; margin-bottom: 20px; }
		h1 { color:#000;}
		pre { background:#eee; padding:10px; font-size:11px; overflow:auto; }
		.backtrace { list-style:none; padding:0; margin:0; }
		tt { background:#59a0bb; color:#fff; display:block; margin:-10px -10px 10px -10px; padding:10px; font-weight:bold; font:13px/18px Arial; }
		p strong { color: #000; }

	</style>
</head>
<body>
	
	<div class="content">
		<p id="message"><?php echo htmlspecialchars($message); ?></p>
	</div>

</body>
</html>