/**
* ========================================================
* Font Stacks
*
* Based on the work of Nathan from Unit Interactive.	
* For titles:
* font-family: Ideal, Alternative, Common, Generic;
* 
* For body copy:
* font-family: Ideal, Fit, Common, Generic;
*
* @section Font Stacks
* @see http://unitinteractive.com/blog/2008/06/26/better-css-font-stacks/
* @since 1.0
* --------------------------------------------------------
*/

=times
{
	font-family: Times, Times New Roman, Georgia, serif;
}

=helvetica
{
	font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}

=helvetica-light
{
	font-family: "HelveticaNeue-Light", "Helvetica Neue Light", "HelveticaLTStd-Light", "Helvetica LT Std Light", "Helvetica Neue", Helvetica, Arial, sans-serif;
	font-weight:300;
}

=myriad
{
	font-family: "Myriad Pro", "MyriadPro", Myriad, "Helvetica Neue", Helvetica, Arial, sans-serif;
}

=baskerville
{
	font-family: Baskerville, Times New Roman, Times, serif;
}

=cambria
{
	font-family: Cambria, Georgia, Times, Times New Roman, serif;
}

=centurygothic
{
	font-family: Century Gothic, Apple Gothic, sans-serif;
}

=monospace
{
	font-family: "Espresso Mono", Consolas, Lucida Console, Monaco, monospace;
}

=franklingothic
{
	font-family: Franklin Gothic Medium, Arial Narrow Bold, Arial, sans-serif;
}

=futura
{
	font-family: Futura, Century Gothic, AppleGothic, sans-serif;
}

=garamond
{
	font-family: Garamond, Hoefler Text, Times New Roman, Times, serif;
}

=geneva
{
	font-family: Geneva, Verdana, Lucida Sans, Lucida Grande, Lucida Sans Unicode, sans-serif;
}

=verdana
{
	font-family: Verdana, Lucida Sans, Lucida Grande, Lucida Sans Unicode, sans-serif;
}

=lucida
{
	font-family: Lucida Sans, Lucida Grande, Lucida Sans Unicode, sans-serif;
}

=georgia
{
	font-family: Georgia, Palatino, Palatino Linotype, Times, Times New Roman, serif;
}

=gillsans
{
	font-family: "Gill Sans", Calibri, Trebuchet, sans-serif;
}

=impact
{
	font-family: Impact, Haettenschweiler, Arial Narrow Bold, sans-serif;
}

=palatino
{
	font-family: Palatino, Palatino Linotype, Hoefler Text, Times, Times New Roman, serif ;
}

=tahoma
{
	font-family: Tahoma, Geneva, Verdana, sans-serif;
}

=trebuchet
{
	font-family: 'Trebuchet MS', Tahoma, Arial, sans-serif;
}

=warnock
{
	font-family: "Warnock Pro", "Goudy Old Style","Palatino","Book Antiqua", Georgia, serif;
}
