<?php

/**
 * Validate Module
 */

/**
 * The CSS level to check - css1, css2, css21, css3, svg, svgbasic, svgtiny, mobile, atsc-tv, tv or none
 */ 
$config['options']['profile'] = 'css3';

/**
 * # The warning level, no for no warnings, 0 for less warnings, 1 or 2 for more warnings
 */
$config['options']['warning'] = 1;