/**
* ========================================================
* Tabs
*
* Tabs Plugin 0.1 for the Blueprint CSS Framework
*
* @section Tabs
* @see http://blueprintcss.org
* @since 1.0
* --------------------------------------------------------
*/

=tabs
{ 
	border-bottom:1px solid #ccc;
	margin:0;
	min-height:auto;
	overflow:auto;
	
	li 
	{
	  	border:1px solid #ccc;
	  	border-bottom:none;
	  	float:left;
	  	line-height:1.5; 
	 	list-style-type:none;
	  	margin:0 .25em 0 0;
	  	padding:0;
	  
	  	a 
		{ 
			background:#ddd;
		  	border:1px solid #eee;
		  	border-bottom:none;
		  	color:#222;
		  	cursor:pointer;
		 	display:block;
		  	float:left;
		  	font-weight:bold;
		  	padding:.15em .33em .25em .33em;
		}
		
		a.selected 
		{ 
		  	background:#666;
		 	border:1px solid #666;
		  	border-bottom:none;
		  	color:#fff;
		  	cursor:default;
		}
		
		a, 
		a:focus, 
		a:hover 	{ text-decoration:none; }
		
		a:focus, 
		a:hover 	{ color:#555; outline:none; }
		
		a.selected:focus, 
		a.selected:hover { color:#fafafa; }
		
	}
	
	li.label 
	{ 
		border:none;
		font-weight:bold;
		line-height:1.5; 
		margin-right:.5em; 
		padding:.25em .33em .25em .33em;
	}
	
}
