/**
 * Easier way to use border-radius
 */
=border-radius($radius)
{
	-webkit-border-radius:$radius;
	-moz-border-radius:$radius;
	border-radius:$radius;
}

=border-top-left-radius($radius)
{
	-webkit-border-top-left-radius:$radius;
	-moz-border-radius-topleft:$radius;
}

=border-top-right-radius($radius)
{
	-webkit-border-top-right-radius:$radius;
	-moz-border-radius-topright:$radius;
}

=border-bottom-left-radius($radius)
{
	-webkit-border-bottom-left-radius:$radius;
	-moz-border-radius-bottomleft:$radius;
}

=border-bottom-right-radius($radius)
{
	-webkit-border-bottom-right-radius:$radius;
	-moz-border-radius-bottomright:$radius;
}

=border-top-radius($radius)
{
	+border-top-left-radius($radius);
	+border-top-right-radius($radius);
}

=border-bottom-radius($radius)
{
	+border-bottom-left-radius($radius);
	+border-bottom-right-radius($radius);
}

=border-left-radius($radius)
{
	+border-top-left-radius($radius);
	+border-bottom-left-radius($radius);
}

=border-right-radius($radius)
{
	+border-top-right-radius($radius);
	+border-bottom-right-radius($radius);
}
